# Contributing to ArviZ
This document outlines only the most common contributions.
Please see the [Contributing guide](https://python.arviz.org/en/latest/contributing/index.html)
on our documentation for a better view of how you can contribute to ArviZ.
We welcome a wide range of contributions, not only code!
Even improving documentation or fixing typos is a valuable contribution to ArviZ.

## Reporting issues
If you encounter any bug or incorrect behaviour while using ArviZ,
please report an issue to our [issue tracker](https://github.com/arviz-devs/arviz/issues).
Please include any supporting information, in particular the version of
ArviZ that you are using.
The issue tracker has several templates available to help in writing the issue
and including useful supporting information.

## Contributing code
Thanks for your interest in contributing code to ArviZ!

* If this is your first time contributing to a project on GitHub, please read through our [step by step](https://python.arviz.org/en/latest/contributing/pr_tutorial.html) guide to contributing to ArviZ
* If you have contributed to other projects on GitHub you can go straight to our [pull request checklist](https://python.arviz.org/en/latest/contributing/pr_checklist.html)

### Adding new features
If you are interested in adding a new feature to ArviZ,
first submit an issue using the "Feature Request" label for the community
to discuss its place and implementation within ArviZ.
